#!/bin/sh
#
# (c) Eduard Bloch <blade@debian.org>, 2003
# generic maintainer script for module-assistant controled packages
# to be sourced or copied as example code

# autodetecting values. They may be overriden by the caller.

guess_source=`basename $0`
export guess_source

guess_package=${guess_source%-src}
guess_package=${guess_package%-source}
export guess_package

topdir=${MOD_TOPDIR:-/usr/src}
tarball=${TARBALL:-/usr/src/$guess_package.tar.gz}
builddir=${BUILDDIR:-${MODULE_LOC:-/usr/src/modules}/$guess_package}
pkgprefix=${PKGPREFIX:-$guess_package} # target base name something like sl-modules
sourcepkg=${SOURCEPKG:-$guess_source} # installed package that provides the source

MA_VARDIR=${MA_VARDIR:-/var/lib/modass}

if [ `id -u` != 0 ] ; then
   ROOT_CMD=${ROOT_CMD:-fakeroot}
fi

action () {
   if [ "$VERBOSE" ] ; then
      echo " $@" >&2
      "$@"
   elif [ "$DRYRUN" ] ; then
      echo " $@" >&2
   else
      "$@"
   fi
}

update () {
   export sourcepkg
   #   action $dpkg -s $sourcepkg  2>/dev/null | grep ^Version: | cut -f2 -d\  > \
   #   $MA_VARDIR/cache/$pkgprefix.cur_version|| rm $MA_VARDIR/cache/$pkgprefix.cur_version 

   aptcache() { LANG=C apt-cache policy $sourcepkg; }
   test -e $MA_VARDIR/cache/$sourcepkg.apt_policy && aptcache() { cat $MA_VARDIR/cache/$sourcepkg.apt_policy ;}
   IFS=''
   if newinfo=`aptcache` ; then
      export newinfo
      echo -n $newinfo |tr -s " " | grep Candidate: | cut -f3 -d\  | tr -d '\n' > \
      $MA_VARDIR/cache/$sourcepkg.avail_version
      instvers=$(echo -n $newinfo |tr -s " " | grep Installed: | cut -f3  -d\  | tr -d '\n')
      if [ "$instvers" = "(none)" ] ; then
         rm -f $MA_VARDIR/cache/$sourcepkg.cur_version
      else
         echo -n $instvers > $MA_VARDIR/cache/$sourcepkg.cur_version
      fi
   else
      rm -f $MA_VARDIR/cache/$sourcepkg.avail_version $MA_VARDIR/cache/$sourcepkg.cur_version
   fi
}

cur_version() {
   cat $MA_VARDIR/cache/$sourcepkg.cur_version 2>/dev/null
}

avail_version() {
   cat $MA_VARDIR/cache/$sourcepkg.avail_version
}

build() {
   test -d $builddir || unpack
   cd $builddir
   shift
   logfile=$MA_VARDIR/cache/$sourcepkg.buildlog.$KVERS.`date +%s`
   eval `echo "$@" | sed -e 's/\ /\n/g' | grep KVERS` 2>&1
   if action $ROOT_CMD debian/rules "$@" 2>&1 | tee $logfile ; then
      action $ROOT_CMD debian/rules echo-deb >> \
      $MA_VARDIR/cache/$sourcepkg.buildstate.$KVERS
   else
      tput smso ; echo BUILD FAILED! ; 
      tput rmso ; echo See $logfile for details.
   fi
}

lastpkg() {
   action tail -n1 $MA_VARDIR/cache/$sourcepkg.buildstate.$KVERS 2>/dev/null
}

unpack() {
   cd $topdir
   echo Extracting the package tarball, $tarball
   if [ -x /usr/bin/unp ] ; then
      action unp $tarball;
   else
      if [ ${tarball%gz} != $tarball ] ; then
         action tar zxf $tarball
      elif [ ${tarball%bz2} != $tarball ] ; then
         action bzcat $tarball | action tar xv
      else
         echo Unknown compression method, $tarball
      fi
      exit 1
   fi
}

download() {
   action apt-get install $sourcepkg
}

purge() {
   action rm -rf $builddir $MA_VARDIR/cache/$sourcepkg.*
}

purge_all() {
   action rm -f `cat $MA_VARDIR/cache/$sourcepkg.buildstate.*`
   purge
}

installed() {
#   action test "`cat $MA_VARDIR/cache/$pkgprefix.cur_version` 2>/dev/null"
#   exit $?
  test -e $MA_VARDIR/cache/$sourcepkg.cur_version
}

prefix() {
   echo $pkgprefix
}

# comment later
#$1 "$@"
